# LiuAlgoTrader
[![Build Status](https://travis-ci.org/amor71/LiuAlgoTrader.svg?branch=master)](https://travis-ci.org/amor71/LiuAlgoTrader)
[![Python 3](https://pyup.io/repos/github/amor71/LiuAlgoTrader/python-3-shield.svg)](https://pyup.io/repos/github/amor71/LiuAlgoTrader/)
[![Updates](https://pyup.io/repos/github/amor71/LiuAlgoTrader/shield.svg)](https://pyup.io/repos/github/amor71/LiuAlgoTrader/)
[![Documentation Status](https://readthedocs.org/projects/liualgotrader/badge/?version=latest)](https://liualgotrader.readthedocs.io/en/latest/?badge=latest)

## Introduction

**LiuAlgoTrader** is a Pythonic all-batteries-included framework
for effective algorithmic trading. The framework is
intended to simplify development, testing,
deployment and evaluating algo trading strategies.

LiuAlgoTrader is Work-In-Progress, however it is a fully
functional framework that may be used almost out-of-the-box.
Assistance in development is highly appreciated,
as well as comments and suggestions. Please check the
Contribution section for further details.

## Documentation

Is available [here](https://liualgotrader.readthedocs.io/en/latest/).

## Development

Would you like to help me complete & evolve LiuAlgoTrader? 
Do you have a suggestion, comment, idea for improvement or 
a have a wish-list item? Don't be shy and email me at 
amichay@sgeltd.com


